%% Simulating Evolutionary Dynamics 

% Comment out next line to superimpose multiple trajectories by running EDM repeatedly 
% close all; 

clear all;


%% Integrate Differential Equation

% Initial conditions (generated randomly below; can also set manually subject to x1+x2+x3=1)
r = gamrnd([1 1 1],1);
init = r / sum(r);
% Set final time of integration
tf=100;
% Choose ode solver and options
options = odeset('RelTol',1e-6,'AbsTol',1e-9);
[T,X]=ode45(@ode4edm,[0 tf],init,options);
% The differential equation 'ode4edm' is constructred below

% Change variables for a planar plot of trajectories on the simplex:
% we can parameterize the affine space with two variables, y1 and y2:
% [x1;x2;x3]=1/3*ones(3,1)+1/sqrt(2)*[-1;1;0]*y1+1/sqrt(6)*[-1;-1;2]*y2
% and obtain y1 and y2 from
% [y1;y2]=[-1/sqrt(2) 1/sqrt(2); -sqrt(3)/sqrt(2)
% -sqrt(3)/sqrt(2)]*[x1-1/3; x2-1/3]

% Trajectroies converted to y coordinates:
Y=[-1/sqrt(2) 1/sqrt(2); -sqrt(3)/sqrt(2) -sqrt(3)/sqrt(2)]*(X(:,1:2)-1/3*ones(size(T,1),2))';
% Plot the boundaries of simplex (in new coordinates) in red:
line([-0.7071  0.7071], [-0.4082 -0.4082],'Color', 'r');
hold on;
line([0.7071 0], [-0.4082   0.8165],'Color', 'r');
line([-0.7071 0], [-0.4082   0.8165],'Color', 'r');
% Plot the trajectories
plot(Y(1,:),Y(2,:))

%% Construct Differential Equation

function dxdt = ode4edm(t,x)

%% Define Payoff

% Rock-Paper-Scissors
w=1;l=1;
%A=[0 -l w;w 0 -l; -l w 0];
%F=A*x;

% 123 Coordination
A=[1 0 0; 0 2 0; 0 0 3];
F=A*x;

%% Set the protocol

for i=1:3;
    for j=1:3;
        % Pairwise proportional imitation
         p(i,j)=x(j)*max(F(j)-F(i),0);
        % BNN
          p(i,j)=max(0,F(j)-x'*F);
        % MJ Smith protocol
          p(i,j)=max(F(j)-F(i),0);
    end;
end;

%% Differential Equation

dxdt=p'*x-x.*(p*ones(3,1));

end
