import numpy as np
from scipy.integrate import odeint
import matplotlib.pyplot as plt

# Constructing the Differential Equation

def ode4edm(x, t):
    
#   Define Payoff

#   Rock-Paper Scissors
    w = 1
    l = 1
    A = np.array([[0, -l, w], [w, 0, -l], [-l, w, 0]])
    F = A.dot(x)
    
#   123 Coordination
#     A = np.array([[1, 0, 0],[0, 2, 0],[0, 0, 3]])
#     F = A.dot(x)
    
#   Set the protocol
    p = np.zeros((3,3))
    for i in range(3):
        for j in range(3):
#           Pairwise proportional imitation
            p[i][j] = x[j] * max(F[j] - F[i], 0)
#           Smith protocol
#             p[i][j] = max(F[j]-F[i], 0)
#   Differential Equation
    dxdt = np.transpose(p).dot(x) - np.multiply(x, (np.transpose(np.sum(p, axis=1))))
    return dxdt

# Initial conditions (generated randomly below; can also set manually subject to x1+x2+x3=1)
r = np.random.gamma([1,1,1],1)
init = r / sum(r)

# Set final time of integration
tf = 100
# Set number of timesteps
t_step = 100000 
# Set linspace of simulation times 
t = np.linspace(0, tf, t_step)
# Solve the ODE                           
sol = odeint(ode4edm, init, t)

# Change variables for a planar plot of trajectories on the simplex:
# we can parameterize the affine space with two variables, y1 and y2:
# [x1;x2;x3]=1/3*ones(3,1)+1/sqrt(2)*[-1;1;0]*y1+1/sqrt(6)*[-1;-1;2]*y2
# and obtain y1 and y2 from
# [y1;y2]=[-1/sqrt(2) 1/sqrt(2); -sqrt(3)/sqrt(2) -sqrt(3)/sqrt(2)]*[x1-1/3; x2-1/3]

# Trajectroies converted to y coordinates:
Y = np.array([[-2**(-1/2), 2**(-1/2)],[ -(3/2)**(1/2), -(3/2)**(1/2)]]).dot((sol[: ,0:2] - 1/3 * np.ones((len(t),2))).transpose())

# Plot the boundaries of simplex (in new coordinates) in red:
plt.plot([-0.7071,  0.7071], [-0.4082, -0.4082],'r')
plt.plot([0.7071, 0], [-0.4082,   0.8165],'r')
plt.plot([-0.7071, 0], [-0.4082,   0.8165],'r')
# Plot the trajectories
plt.plot(Y[0], Y[1])
plt.show()
