function [rho,P,lam] = rateboundOffBy1(sys,k)


% Perform Bisection
warning off
rholb = 0;
rhoub = 2;
rhotol = 1e-3;
Popt = []; lamopt = [];
while rhoub-rholb>rhotol
    % Select rho
    rho = (rholb+rhoub)/2;

    % Sector IQC
    % Psi = [L -1; -m 1]
    Psi1 = [k -1; -1 1];
    M1 = [0 1; 1 0];
    
    % Weighted Off-by-1 IQC
    % Psi = ss(0,[-L 1],[rho^2;0],[L -1; -m 1],1);
    Psi2 = ss(0,[-k 1],[rho^2;0],[k -1; -1 1],1);
    M2 = [0 1; 1 0];
    
    % Extended System
    %  [z1;z2] = [Psi1; Psi2]*[G;1]    
    Gext = [Psi1; Psi2]*[sys;1];
    [A,B,C,D] = ssdata(Gext);
    [nx,nu] = size(B);   
    
    cvx_begin sdp quiet
        variables P(nx,nx) lambda;
        P>=0;
        lambda>=0;
        
        LMI1 = [A B]'*P*[A B];
        LMI2 = blkdiag(P,zeros(nu));
        LMI3 = [C D]'*blkdiag(lambda*M1,M2)*[C D];

        LMI1 - rho^2*LMI2 + LMI3 <=0;
    cvx_end
    
    if isequal(cvx_status,'Solved')
        rhoub = rho;
        flg = 1;
        rhoopt = rho;
        Popt = P;
        lamopt = lambda;
    else
        flg = 0;
        rholb = rho;
    end
%     fprintf([' rho = %4.3f \t Newlb = %4.3f \t Newub = ' ...
%         '%4.3f \t Solve = %d \n'],rho,rholb,rhoub,flg);
end
% fprintf('\n');
warning on

% Store results
rho = rhoub;
P = Popt;
lam = lamopt;