function [rho,P] = rateboundSector(sys,k)

% Grab system data
Gext = [sys;1];
[A,B,C,D] = ssdata(Gext);
nx = size(A,1);
nu = size(B,2);
    
% Sector-bound IQC
%   M = [-2*m*L m+L; m+L -2];
M = [-2*k 1+k; 1+k -2];

% Perform Bisection
warning off
rholb = 0;
rhoub = 2;
rhotol = 1e-3;
Popt = [];
while rhoub-rholb>rhotol
    rho = (rholb+rhoub)/2;
    
    cvx_begin sdp quiet
        variables P(nx,nx);
        P>=0;
        LMI1 = [A B]'*P*[A B];
        LMI2 = blkdiag(P,zeros(nu));
        LMI3 = [C D]'*M*[C D];

        LMI1 - rho^2*LMI2 + LMI3 <=0;
    cvx_end
    
    if isequal(cvx_status,'Solved')
        rhoub = rho;
        flg = 1;
        Popt = P;
    else
        flg = 0;
        rholb = rho;
    end
%     fprintf([' rho = %4.3f \t Newlb = %4.3f \t Newub = ' ...
%         '%4.3f \t Solve = %d \n'],rho,rholb,rhoub,flg);
end
warning on

% Store results
rho = rhoub;
P = Popt;